@@ -3,9 +3,7 @@ import os
 import random
 import requests
 import time
-import uuid
 
-from cached_property import cached_property
 from copy import deepcopy
 
 from .logger import logger
@@ -16,14 +14,12 @@ from .records import Record
 from .settings import S3_URL_PREFIX, BASE_URL
 from .utils import (
     extract_id,
-    now,
     get_embed_link,
-    get_embed_data,
     add_signed_prefix_as_needed,
     remove_signed_prefix_as_needed,
     get_by_path,
 )
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import List, Optional
 
 
 class Children(object):
